.. _references:

############
 References
############

This is the technical documentation of icclim. You should find here an
overview of the public API as well as the description of internal
mechanisms of icclim.

|  For beginner, it is recommended to start with :ref:`tutorials`.
|  For more abstract discussion about icclim, see :ref:`explanation`.

.. toctree::
   :maxdepth: 3
   :caption: References

   icclim_index_api
   ecad_functions_api
   dcsc_functions_api
   generic_functions_api
   custom_indices
   output_metadata
   release_notes
   api/index
